List of contributors
====================

If you're a contributor and you're not listed here, we appologize for
that omission, and ask you to add yourself to the list.

- Medardo Rodríguez started this package and wrote most of it.

- Dunia Trujillo has fixed bugs, tested the software and also
  contributed code.

- Manuel Vázquez has contribute code and reorganize the package for
  the 1.1.x release series. He has contributed also to the
  documentation and docstring in reST format with doctests.
